use warnings;
use strict;

package Mozilla::Persona::Aliases::MailConfig;
use base 'Mozilla::Persona::Aliases';

use Log::Report         qw/persona/;
use Mail::ExpandAliases ();

=chapter NAME
Mozilla::Persona::Aliases::MailConfig - multiple personalities like email

=chapter SYNOPSIS
  # add to the configation of $domain.json
  { ...
    "aliases" : {
      "class" : "Mozilla::Persona::Aliases::MailConfig"
      "file" : "/etc/services"
    },
    ...
  }

=chapter DESCRIPTION
The Aliases objects check whether a certain email-address relates to
the specified user.  This class uses the alias tables of the standard
email programs to expand the username.  All unix mailers use the same
"aliases" file format, and usually F</etc/aliases>.

=chapter METHOD

=section Constructors

=c_method new OPTIONS
=option  file FILENAME
=default file see M<Mail::ExpandAliases::new()>
=cut

sub init($)
{   my ($self, $args) = @_;

    # Mail::ExpandAliases support only one file
    $self->{MPAM_file} = delete $args->{file};
    $self->SUPER::init($args);
    $self;
}

sub _table()
{   my $self = shift;
    $self->{MPAM_table} ||= Mail::ExpandAliases->new($self->{MPAM_file});
}

sub for($)
{   my ($self, $user) = @_;
    $user =~ s/\@.*//;
    $self->_table->expand($user);
}

1;
