use warnings;
use strict;

package Mozilla::Persona::Validate;

use Log::Report  qw/persona/;

=chapter NAME
Mozilla::Persona::Validate - validate the existence of the user

=chapter SYNOPSIS
  # add to the configation of $domain.json
  { ...
    "validate" : {
      "class" : "Mozilla::Persona::Validate::Table"
      ...options for new()...
    },
    ...
  }

=chapter DESCRIPTION
The validator object must ensure that the user/password combination
is valid.  Various approaches are possible, but only a few implemented.
Please contribute.

Ideas/implementations for validators:

=over 4

=item * Mozilla::Persona::Validate::Table
(To be implemented)  Maintained is a table of username/password
combinations (passwords are always kept encrypted).

=item * M<Mozilla::Persona::Validate::IMAPTalk>
The M<Mail::IMAPTalk> implementation is used to contact an IMAP4 server
with the username/password.  When login for that server is successful,
then the user is valid, access is granted.

=item * Mozilla::Persona::Validate::IMAPClient>
(To be implemented) Use the more popular M<Mail::IMAPClient> to validate.

=item * Mozilla::Persona::Validate::HtAccess>
(To be implemented) Use htaccess format files, which simplifies
integration with websites.

=back

=chapter METHODS

=section Constructors

=c_method new OPTIONS
=cut

sub new(%) {my $class = shift; (bless {}, $class)->init({@_}) }
sub init($)
{   my ($self, $args) = @_;
    $self;
}

#---------------
=section Validation

=method isValid USER, PASSWORD
=cut

sub isValid($$) { panic }

1;
